#ifndef NT2_INCLUDE_FUNCTIONS_ACOSD_HPP_INCLUDED
#define NT2_INCLUDE_FUNCTIONS_ACOSD_HPP_INCLUDED

#include <nt2/trigonometric/include/functions/acosd.hpp>

#endif
